extract_wireframe_entities_that_need_specializations_removed

Function extract_wireframe_entities_that_need_specializations_removed 

pub fn extract_wireframe_entities_that_need_specializations_removed(
    entities_needing_specialization: Extract<'_, '_, Res<'_, WireframeEntitiesNeedingSpecialization>>,
    dirty_wireframe_specializations: ResMut<'_, DirtyWireframeSpecializations>,
)
A system that adds entities that were judged to need their wireframe specializations removed to the appropriate table in DirtyWireframeSpecializations.